==> mywwwatcher-3.1.tbz: www/mywwwatcher/stat.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");

?>

<body leftmargin="13" topmargin="13" bottommargin="30" rightmargin="5" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<b>" . STAT . "</b><br/><br/>\n";


$result = mysql_query ("show status");
echo mysql_error();

echo "\n<table style=\"width: 350\" class=\"border\">\n";

$queries1 = array ('uptime','questions','Bytes_received','Bytes_sent','connections');   // status
$queries2 = array ('character_set_client','character_set_connection','character_set_database',
                   'character_set_results','character_set_server','collation_connection',
                   'collation_database','collation_server');   // variables

foreach ($queries1 as $query)   {
    $result = mysql_query ("show status like '$query'");
    echo "<tr><td>" . mysql_result ($result,0,0) . "</td><td>" . mysql_result ($result,0,1) . "</td></tr>\n";
}

foreach ($queries2 as $query)   {
    $result = mysql_query ("show variables like '$query'");
    if (mysql_num_rows ($result) > 0)
        echo "<tr><td>" . mysql_result ($result,0,0) . "</td><td>" . mysql_result ($result,0,1) . "</td></tr>\n";
}

echo "</table>\n";

echo "<br/><br/>" . CHARSET_WARNING;

$ver = mysql_query ("show variables like 'version'");

if ( ereg ("^3\..*$", mysql_result ($ver,0,1)) or ereg ("^4\.0.*$", mysql_result ($ver,0,1)) ) echo VER_BAD;

include ("include/foot.inc.php");
?>

==> mywwwatcher-3.2.tbz: www/mywwwatcher/stat.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");

?>

<body  id="frm_right" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<strong>" . STAT . "</strong><br/><br/>\n";

$result = mysql_query ("show status");
echo mysql_error();

echo "\n<table style=\"width: 350px;\" class=\"border\">\n";

$queries1 = array ('uptime','questions','Bytes_received','Bytes_sent','connections');   // status
$queries2 = array ('character_set_client','character_set_connection','character_set_database',
                   'character_set_results','character_set_server','collation_connection',
                   'collation_database','collation_server');   // variables

foreach ($queries1 as $query)   {
    $result = mysql_query ("show status like '$query'");
    echo "<tr><td>" . mysql_result ($result,0,0) . "</td><td>" . mysql_result ($result,0,1) . "</td></tr>\n";
}

foreach ($queries2 as $query)   {
    $result = mysql_query ("show variables like '$query'");
    if (mysql_num_rows ($result) > 0)
        echo "<tr><td>" . mysql_result ($result,0,0) . "</td><td>" . mysql_result ($result,0,1) . "</td></tr>\n";
}

echo "</table>\n";

echo "<br/><br/>" . CHARSET_WARNING;

$ver = mysql_query ("show variables like 'version'");

if ( ereg ("^3\..*$", mysql_result ($ver,0,1)) or ereg ("^4\.0.*$", mysql_result ($ver,0,1)) ) echo VER_BAD;

include ("include/sqltips.inc.php");
$rand = rand(0,count($tip)-1);
echo "<br/><br/><br/><strong>Tip:</strong><br/>" . $tip[$rand];



include ("include/foot.inc.php");
?>
